@@ -19,9 +19,14 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *)
 
-
 open BatNumber
 
+##V>=5##module Pervasives = Stdlib
+
+(*$inject
+##V>=5##module Pervasives = Stdlib
+*)
+
 module BaseFloat = struct
   type t = float
   let zero, one = 0., 1.
@@ -57,21 +62,51 @@ let approx_equal ?(epsilon = 1e-5) f1 f2 = abs_float (f1 -. f2) < epsilon
    not (approx_equal 1.5 1.45)
 *)
 
-external exp : float -> float = "caml_exp_float" "exp" "float"
-external log : float -> float = "caml_log_float" "log" "float"
-external log10 : float -> float = "caml_log10_float" "log10" "float"
-external cos : float -> float = "caml_cos_float" "cos" "float"
-external sin : float -> float = "caml_sin_float" "sin" "float"
-external tan : float -> float = "caml_tan_float" "tan" "float"
-external acos : float -> float = "caml_acos_float" "acos" "float"
-external asin : float -> float = "caml_asin_float" "asin" "float"
-external atan : float -> float = "caml_atan_float" "atan" "float"
-external atan2 : float -> float -> float = "caml_atan2_float" "atan2" "float"
-external cosh : float -> float = "caml_cosh_float" "cosh" "float"
-external sinh : float -> float = "caml_sinh_float" "sinh" "float"
-external tanh : float -> float = "caml_tanh_float" "tanh" "float"
-external ceil : float -> float = "caml_ceil_float" "ceil" "float"
-external floor : float -> float = "caml_floor_float" "floor" "float"
+external exp : float -> float = "caml_exp_float" "exp"
+##V<4.3##  "float"
+##V>=4.3##  [@@unboxed] [@@noalloc]
+external log : float -> float = "caml_log_float" "log"
+##V<4.3##  "float"
+##V>=4.3##  [@@unboxed] [@@noalloc]
+external log10 : float -> float = "caml_log10_float" "log10"
+##V<4.3##  "float"
+##V>=4.3##  [@@unboxed] [@@noalloc]
+external cos : float -> float = "caml_cos_float" "cos"
+##V<4.3##  "float"
+##V>=4.3##  [@@unboxed] [@@noalloc]
+external sin : float -> float = "caml_sin_float" "sin"
+##V<4.3##  "float"
+##V>=4.3##  [@@unboxed] [@@noalloc]
+external tan : float -> float = "caml_tan_float" "tan"
+##V<4.3##  "float"
+##V>=4.3##  [@@unboxed] [@@noalloc]
+external acos : float -> float = "caml_acos_float" "acos"
+##V<4.3##  "float"
+##V>=4.3##  [@@unboxed] [@@noalloc]
+external asin : float -> float = "caml_asin_float" "asin"
+##V<4.3##  "float"
+##V>=4.3##  [@@unboxed] [@@noalloc]
+external atan : float -> float = "caml_atan_float" "atan"
+##V<4.3##  "float"
+##V>=4.3##  [@@unboxed] [@@noalloc]
+external atan2 : float -> float -> float = "caml_atan2_float" "atan2"
+##V<4.3##  "float"
+##V>=4.3##  [@@unboxed] [@@noalloc]
+external cosh : float -> float = "caml_cosh_float" "cosh"
+##V<4.3##  "float"
+##V>=4.3##  [@@unboxed] [@@noalloc]
+external sinh : float -> float = "caml_sinh_float" "sinh"
+##V<4.3##  "float"
+##V>=4.3##  [@@unboxed] [@@noalloc]
+external tanh : float -> float = "caml_tanh_float" "tanh"
+##V<4.3##  "float"
+##V>=4.3##  [@@unboxed] [@@noalloc]
+external ceil : float -> float = "caml_ceil_float" "ceil"
+##V<4.3##  "float"
+##V>=4.3##  [@@unboxed] [@@noalloc]
+external floor : float -> float = "caml_floor_float" "floor"
+##V<4.3##  "float"
+##V>=4.3##  [@@unboxed] [@@noalloc]
 external frexp : float -> float * int = "caml_frexp_float"
 external ldexp : float -> int -> float = "caml_ldexp_float"
 external modf : float -> float * float = "caml_modf_float"
@@ -121,8 +156,8 @@ let round x =
    a temporary fix made necessary by BatFloat overriding the (=)
    operator. Hugh. *)
 (*$T round
-   Pervasives.(=) (List.map round [1.1; 2.4; 3.3; 3.5; 4.99]) [1.; 2.; 3.; 4.; 5.]
-   Pervasives.(=) (List.map round [-1.1; -2.4; -3.3; -3.5; -4.99]) [-1.; -2.; -3.; -4.; -5.]
+   (List.map round [1.1; 2.4; 3.3; 3.5; 4.99]) = [1.; 2.; 3.; 4.; 5.]
+   (List.map round [-1.1; -2.4; -3.3; -3.5; -4.99]) = [-1.; -2.; -3.; -4.; -5.]
    round 0.499999999999999944 = 0.
    round (-0.499999999999999944) = 0.
 *)
@@ -131,7 +166,7 @@ let round_to_int x =
   int_of_float (round x)
 
 (*$T round_to_int
-   Pervasives.(=) (List.map round_to_int [1.1; 2.4; 3.3; 3.5; 4.99]) [1; 2; 3; 4; 5]
+   (List.map round_to_int [1.1; 2.4; 3.3; 3.5; 4.99]) = [1; 2; 3; 4; 5]
 *)
 
 module Infix = struct
@@ -147,11 +182,17 @@ let max (x:float) y = if x < y then y else x
 (* Fix definitions for performance *)
 external of_float : float -> float = "%identity"
 external to_float : float -> float = "%identity"
-external sqrt : float -> float = "caml_sqrt_float" "sqrt" "float"
+external sqrt : float -> float = "caml_sqrt_float" "sqrt"
+##V<4.3##  "float"
+##V>=4.3##  [@@unboxed] [@@noalloc]
 external neg : float -> float = "%negfloat"
 external abs : float -> float = "%absfloat"
-external modulo : float -> float -> float = "caml_fmod_float" "fmod" "float"
-external pow : float -> float -> float = "caml_power_float" "pow" "float"
+external modulo : float -> float -> float = "caml_fmod_float" "fmod"
+##V<4.3##  "float"
+##V>=4.3##  [@@unboxed] [@@noalloc]
+external pow : float -> float -> float = "caml_power_float" "pow"
+##V<4.3##  "float"
+##V>=4.3##  [@@unboxed] [@@noalloc]
 external of_int : int -> float = "%floatofint"
 external to_int : float -> int = "%intoffloat"
 external of_float : float -> float = "%identity"
@@ -160,7 +201,9 @@ external ( + ) : t -> t -> t = "%addfloat"
 external ( - ) : t -> t -> t = "%subfloat"
 external ( * ) : t -> t -> t = "%mulfloat"
 external ( / ) : t -> t -> t = "%divfloat"
-external ( ** ) : t -> t -> t = "caml_power_float" "pow" "float"
+external ( ** ) : t -> t -> t = "caml_power_float" "pow"
+##V<4.3##  "float"
+##V>=4.3##  [@@unboxed] [@@noalloc]
 
 
 type bounded = t
@@ -230,23 +273,23 @@ let round_to_string ?(digits=0) x =
 
 (*$T round_to_string
    List.mem (round_to_string 3.) ["3."; "3"]
-   Pervasives.(=) (round_to_string ~digits:0 3.) (round_to_string 3.)
-   Pervasives.(=) (round_to_string ~digits:1 3.) "3.0"
-   Pervasives.(=) (round_to_string ~digits:1 0.) "0.0"
-   Pervasives.(=) (round_to_string ~digits:1 epsilon_float) "0.0"
-   Pervasives.(=) (round_to_string ~digits:3 1.23456) "1.235"
-   Pervasives.(=) (round_to_string ~digits:3 (- 1.23456)) "-1.235"
-   Pervasives.(=) (round_to_string ~digits:3 1.98765) "1.988"
-   Pervasives.(=) (round_to_string ~digits:3 (- 1.98765)) "-1.988"
+   (round_to_string ~digits:0 3.) = (round_to_string 3.)
+   (round_to_string ~digits:1 3.) = "3.0"
+   (round_to_string ~digits:1 0.) = "0.0"
+   (round_to_string ~digits:1 epsilon_float) = "0.0"
+   (round_to_string ~digits:3 1.23456) = "1.235"
+   (round_to_string ~digits:3 (- 1.23456)) = "-1.235"
+   (round_to_string ~digits:3 1.98765) = "1.988"
+   (round_to_string ~digits:3 (- 1.98765)) = "-1.988"
    Result.(catch (round_to_string ~digits:(-1)) 3. |> is_exn (Invalid_argument "Float.round_to_string"))
    List.mem (round_to_string 0.5) ["0"; "0."; "1"; "1."]
    List.mem (round_to_string (-0.5)) ["-1"; "-1."; "0"; "0."; "-0"; "-0."]
    List.mem (round_to_string ~digits:2 0.215) ["0.21"; "0.22"]
    List.mem (round_to_string ~digits:2 (-0.215)) ["-0.22"; "-0.21"]
-   Pervasives.(=) (round_to_string ~digits:32 epsilon_float) "0.00000000000000022204460492503131"
+   (round_to_string ~digits:32 epsilon_float) = "0.00000000000000022204460492503131"
    List.mem (round_to_string ~digits:42 infinity) ["inf"; "infinity"]
    List.mem (round_to_string ~digits:0 neg_infinity) ["-inf"; "-infinity"]
-   List.for_all (fun digits -> Pervasives.(=) "nan" (String.sub (round_to_string ~digits nan) 0 3)) [0; 42]
+   List.for_all (fun digits -> (=) "nan" (String.sub (round_to_string ~digits nan) 0 3)) [0; 42]
 *)
 
 
