@@ -18,6 +18,12 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *)
 
+##V>=5##module Pervasives = Stdlib
+
+(*$inject
+##V>=5##module Pervasives = Stdlib
+*)
+
 (** {6 Exceptions} *)
 
 exception No_more_elements
@@ -38,11 +44,16 @@ type 'a mappable = 'a t
 
 (** {6 Access} *)
 
-let nil    = Lazy.lazy_from_val Nil
+let lazy_from_val v =
+##V<5##  Lazy.lazy_from_val v
+##V>=5## Lazy.from_val v
+
+let nil    =
+  lazy_from_val Nil
 
 let next l = Lazy.force l
 
-let cons h t = Lazy.lazy_from_val (Cons(h, t))
+let cons h t = lazy_from_val (Cons(h, t))
 
 let ( ^:^ ) = cons
 
@@ -266,11 +277,11 @@ let at list n =
 
 let nth = at
 
-let rev list = fold_left (fun acc x -> Lazy.lazy_from_val (Cons (x, acc))) nil list
+let rev list = fold_left (fun acc x -> lazy_from_val (Cons (x, acc))) nil list
 
 (**Revert a list, convert it to a lazy list.
    Used as an optimisation.*)
-let rev_of_list (list:'a list) = List.fold_left (fun acc x -> Lazy.lazy_from_val (Cons (x, acc))) nil list
+let rev_of_list (list:'a list) = List.fold_left (fun acc x -> lazy_from_val (Cons (x, acc))) nil list
 
 let eager_append (l1 : 'a t) (l2 : 'a t) =
   let rec aux list =
@@ -282,7 +293,7 @@ let eager_append (l1 : 'a t) (l2 : 'a t) =
 let rev_append (l1 : 'a t) (l2 : 'a t) =
   let rec aux list acc =
     match next list with
-    | Cons (x, t) -> aux t (Lazy.lazy_from_val (Cons (x, acc)))
+    | Cons (x, t) -> aux t (lazy_from_val (Cons (x, acc)))
     | Nil -> acc
   in aux l1 l2
 
@@ -331,10 +342,10 @@ let combinations l =
   in gen l
 
 (*$T combinations
-    List.sort Pervasives.compare (to_list (combinations [1;2;3])) = \
+    List.sort Legacy.compare (to_list (combinations [1;2;3])) = \
    [[]; [1]; [1;2]; [1;2;3]; [1;3]; [2]; [2;3]; [3]]
      to_list (combinations []) = [[]]
-     List.sort Pervasives.compare (to_list (combinations [1])) = [[]; [1]]
+     List.sort Legacy.compare (to_list (combinations [1])) = [[]; [1]]
 *)
 
 let permutations l =
@@ -353,7 +364,7 @@ let permutations l =
   in choose_first l []
 
 (*$T permutations
-    List.sort Pervasives.compare (to_list (permutations [1;2;3])) = \
+    List.sort Legacy.compare (to_list (permutations [1;2;3])) = \
    [[1;2;3]; [1;3;2]; [2;1;3]; [2;3;1]; [3;1;2]; [3;2;1]]
      to_list (permutations []) = [[]]
      to_list (permutations [1]) = [[1]]
@@ -421,13 +432,13 @@ let of_stream s =
    Eager conversion from lists
 *)
 let eager_of_list l =
-  ListLabels.fold_right ~init: nil ~f: (fun x acc -> Lazy.lazy_from_val (Cons (x, acc))) l
+  ListLabels.fold_right ~init: nil ~f: (fun x acc -> lazy_from_val (Cons (x, acc))) l
 
 (**
    Eager conversion from array
 *)
 let of_array l =
-  ArrayLabels.fold_right ~init: nil ~f: (fun x acc -> Lazy.lazy_from_val (Cons (x, acc))) l
+  ArrayLabels.fold_right ~init: nil ~f: (fun x acc -> lazy_from_val (Cons (x, acc))) l
 
 (**
    Lazy conversion from enum
