@@ -20,6 +20,12 @@
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *)
 
+##V>=5##module Pervasives = Stdlib
+
+(*$inject
+##V>=5##module Pervasives = Stdlib
+*)
+
 (* A concrete implementation for the direct balanced maps structure,
    without carrying the ordering information with the data.
 
@@ -53,6 +59,9 @@ module Concrete = struct
 
   let empty = Empty
 
+  let is_empty m =
+    m = Empty
+
   (* The create and bal functions are from stdlib's map.ml (3.12)
      differences from the old (extlib) implementation :
 
@@ -105,6 +114,11 @@ module Concrete = struct
     | Node (l, _, _, _, _) -> min_binding l
     | Empty -> raise Not_found
 
+  let rec min_binding_opt = function
+    | Node (Empty, k, v, _, _) -> Some (k, v)
+    | Node (l, _, _, _, _) -> min_binding_opt l
+    | Empty -> None
+
   let get_root = function
     | Empty -> raise Not_found
     | Node (_, k, v, _, _) -> k, v
@@ -112,7 +126,7 @@ module Concrete = struct
   let pop_min_binding s =
     let mini = ref (get_root s) in
     let rec loop = function
-      | Empty -> assert(false)
+      | Empty -> assert(false)  (* get_root already raises Not_found on empty map *)
       | Node(Empty, k, v, r, _) -> mini := (k, v); r
       | Node(l, k, v, r, _) -> bal (loop l) k v r
     in
@@ -122,12 +136,17 @@ module Concrete = struct
   let rec max_binding = function
     | Node (_, k, v, Empty, _) -> k, v
     | Node (_, _, _, r, _) -> max_binding r
-    | Empty -> invalid_arg "PMap.max_binding: empty tree"
+    | Empty -> raise Not_found
+
+  let rec max_binding_opt = function
+    | Node (_, k, v, Empty, _) -> Some (k, v)
+    | Node (_, _, _, r, _) -> max_binding_opt r
+    | Empty -> None
 
   let pop_max_binding s =
     let maxi = ref (get_root s) in
     let rec loop = function
-      | Empty -> assert(false)
+      | Empty ->  assert(false)  (* get_root already raises Not_found on empty map *)
       | Node (l, k, v, Empty, _) -> maxi := (k, v); l
       | Node (l, k, v, r, _) -> bal l k v (loop r)
     in
@@ -137,7 +156,7 @@ module Concrete = struct
   let rec remove_min_binding = function
     | Node (Empty, _, _, r, _) -> r
     | Node (l, k, v, r, _) -> bal (remove_min_binding l) k v r
-    | Empty -> invalid_arg "PMap.remove_min_binding"
+    | Empty -> raise Not_found
 
   let merge t1 t2 =
     match t1, t2 with
@@ -149,15 +168,25 @@ module Concrete = struct
 
   let add x d cmp map =
     let rec loop = function
-      | Node (l, k, v, r, h) ->
+      | Node (l, k, v, r, h) as node ->
         let c = cmp x k in
-        if c = 0 then Node (l, x, d, r, h)
+        if c = 0 then
+          if d == v then
+            node
+          else
+            Node (l, x, d, r, h)
         else if c < 0 then
           let nl = loop l in
-          bal nl k v r
+          if nl == l then
+            node 
+          else
+            bal nl k v r
         else
           let nr = loop r in
-          bal l k v nr
+          if nr == r then
+            node
+          else
+            bal l k v nr
       | Empty -> Node (Empty, x, d, Empty, 1) in
     loop map
 
@@ -171,6 +200,88 @@ module Concrete = struct
       | Empty -> raise Not_found in
     loop map
 
+  let rec find_first_helper_found k0 v0 f = function
+    | Empty -> (k0, v0)
+    | Node (l, k, v, r, _) ->
+       if f k
+       then find_first_helper_found k v f l
+       else find_first_helper_found k0 v0 f r
+
+  let rec find_first f m =
+    match m with
+    | Empty -> raise Not_found
+    | Node (l, k, v, r, _) ->
+       if f k
+       then find_first_helper_found k v f l
+       else find_first f r
+
+  let rec find_first_opt f m =
+    match m with
+    | Empty -> None
+    | Node (l, k, v, r, _) ->
+       if f k
+       then Some (find_first_helper_found k v f l)
+       else find_first_opt f r
+
+  let rec find_last_helper_found k0 v0 f = function
+    | Empty -> (k0, v0)
+    | Node (l, k, v, r, _) ->
+       if f k
+       then find_last_helper_found k v f r
+       else find_last_helper_found k0 v0 f l
+
+  let rec find_last f m =
+    match m with 
+    | Empty -> raise Not_found
+    | Node (l, k, v, r, _) ->
+       if f k
+       then find_last_helper_found k v f r
+       else find_last f l
+
+  let rec find_last_opt f m =
+    match m with 
+    | Empty -> None
+    | Node (l, k, v, r, _) ->
+       if f k
+       then Some (find_last_helper_found k v f r)
+       else find_last_opt f l
+
+  (*$T find_first
+              (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_first (fun x -> x >= 0)) = ((1, 11))
+              (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_first (fun x -> x >= 1)) = ((1, 11))
+              (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_first (fun x -> x >= 2)) = ((2, 12))
+              (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_first (fun x -> x >= 3)) = ((3, 13))
+    try ignore(empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_first (fun x -> x >= 4)); false with Not_found -> true
+    try ignore(empty |>                                     find_first (fun x -> x >= 3)); false with Not_found -> true
+  *)
+
+  (*$T find_first_opt
+    (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_first_opt (fun x -> x >= 0)) = (Some (1, 11))
+    (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_first_opt (fun x -> x >= 1)) = (Some (1, 11))
+    (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_first_opt (fun x -> x >= 2)) = (Some (2, 12))
+    (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_first_opt (fun x -> x >= 3)) = (Some (3, 13))
+    (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_first_opt (fun x -> x >= 4)) = (None)
+    (empty |>                                     find_first_opt (fun x -> x >= 3)) = (None)
+  *)
+
+  (*$T find_last
+              (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_last (fun x -> x <= 1)) = (1, 11)
+              (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_last (fun x -> x <= 2)) = (2, 12)
+              (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_last (fun x -> x <= 3)) = (3, 13)
+              (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_last (fun x -> x <= 4)) = (3, 13)
+    try ignore(empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_last (fun x -> x <= 0)); false with Not_found -> true
+    try ignore(empty |>                                     find_last (fun x -> x <= 3)); false with Not_found -> true
+  *)
+
+  (*$T find_last_opt
+    (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_last_opt (fun x -> x <= 0)) = None
+    (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_last_opt (fun x -> x <= 1)) = Some (1, 11)
+    (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_last_opt (fun x -> x <= 2)) = Some (2, 12)
+    (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_last_opt (fun x -> x <= 3)) = Some (3, 13)
+    (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_last_opt (fun x -> x <= 4)) = Some (3, 13)
+    (empty |>                                     find_last_opt (fun x -> x <= 3)) = None
+  *)
+
   let find_option x cmp map =
     try Some (find x cmp map)
     with Not_found -> None
@@ -181,10 +292,22 @@ module Concrete = struct
 
   let remove x cmp map =
     let rec loop = function
-      | Node (l, k, v, r, _) ->
+      | Node (l, k, v, r, _) as node ->
         let c = cmp x k in
-        if c = 0 then merge l r else
-        if c < 0 then bal (loop l) k v r else bal l k v (loop r)
+        if c = 0 then
+          merge l r
+        else if c < 0 then
+          let nl = loop l in
+          if nl == l then
+            node
+          else 
+            bal nl k v r
+        else
+          let nr = loop r in
+          if nr == r then
+            node
+          else
+            bal l k v nr
       | Empty -> Empty in
     loop map
 
@@ -210,17 +333,56 @@ module Concrete = struct
     else
       let rec loop = function
         | Empty -> raise Not_found
-        | Node(l, k, v, r, h) ->
-          let c = cmp k1 k in
-          if c = 0 then
-            Node(l, k2, v2, r, h)
-          else if c < 0 then
-            Node(loop l, k, v, r, h)
-          else
-            Node(l, k, v, loop r, h)
+        | Node(l, k, v, r, h) as node ->
+           let c = cmp k1 k in
+           if c = 0 then
+             if v == v2 && k == k2 then
+               node
+             else 
+               Node(l, k2, v2, r, h)
+           else if c < 0 then
+             let nl = loop l in
+             if nl == l then
+               node
+             else 
+               Node(nl, k, v, r, h)
+           else
+             let nr = loop r in
+             if nr == r then
+               node
+             else 
+               Node(l, k, v, nr, h)
       in
       loop map
 
+  let rec update_stdlib x f cmp = function
+    |  Empty ->
+        begin match f None with
+        | None -> Empty
+        | Some data -> Node(Empty, x, data, Empty, 1)
+        end
+    | Node (l, v, d, r, h) as m ->
+       let c = cmp x v in
+       if c = 0 then
+         begin
+           match f (Some d) with
+           | None -> merge l r
+           | Some data ->
+              if d == data
+              then m
+              else Node(l, x, data, r, h)
+         end
+       else if c < 0 then
+         let ll = update_stdlib x f cmp l in
+         if l == ll
+         then m
+         else bal ll v d r
+       else
+         let rr = update_stdlib x f cmp r in
+         if r == rr
+         then m
+         else bal l v d rr
+
   let mem x cmp map =
     let rec loop = function
       | Node (l, k, _v, r, _) ->
@@ -367,15 +529,23 @@ module Concrete = struct
     | Empty -> t
     | Node (l, k, v, r, _) -> rev_cons_iter r (C (k, v, l, t))
 
-  let rec enum_next l () = match !l with
+  let rec cons_iter_from cmp k2 m e =
+    match m with
+    | Empty -> e
+    | Node (l, k, v, r, _) ->
+       if cmp k2 k <= 0
+       then cons_iter_from cmp k2 l (C (k, v, r, e))
+       else cons_iter_from cmp k2 r e
+
+  let enum_next l () = match !l with
       E -> raise BatEnum.No_more_elements
     | C (k, v, m, t) -> l := cons_iter m t; (k, v)
 
-  let rec enum_backwards_next l () = match !l with
+  let enum_backwards_next l () = match !l with
       E -> raise BatEnum.No_more_elements
     | C (k, v, m, t) -> l := rev_cons_iter m t; (k, v)
 
-  let rec enum_count l () =
+  let enum_count l () =
     let rec aux n = function
       | E -> n
       | C (_, _, m, t) -> aux (n + 1 + cardinal m) t
@@ -411,9 +581,9 @@ module Concrete = struct
      build the result map. The unusual parameter order was chosen to
      reflect this.  *)
   let filterv f t cmp =
-    foldi (fun k a acc -> if f a then add k a cmp acc else acc) t empty
+    foldi (fun k a acc -> if f a then acc else remove k cmp acc) t t
   let filter f t cmp =
-    foldi (fun k a acc -> if f k a then add k a cmp acc else acc) t empty
+    foldi (fun k a acc -> if f k a then acc else remove k cmp acc) t t
   let filter_map f t cmp =
     foldi (fun k a acc -> match f k a with
       | None   -> acc
@@ -451,6 +621,10 @@ module Concrete = struct
     (empty |> add 0 1 |> add 1 1 |> choose) (empty |> add 1 1 |> add 0 1 |> choose)
    *)
 
+  let choose_opt m =
+    try Some (choose m)
+    with Not_found -> None
+
   let any = function
     | Empty -> raise Not_found
     | Node (_, k, v, _, _) -> (k,v)
@@ -556,7 +730,7 @@ module Concrete = struct
     | Some d -> join t1 v d t2
     | None -> concat t1 t2
 
-  let rec merge f cmp12 s1 s2 =
+  let merge f cmp12 s1 s2 =
     let rec loop s1 s2 =
       match (s1, s2) with
       | (Empty, Empty) -> Empty
@@ -571,7 +745,7 @@ module Concrete = struct
         assert false in
     loop s1 s2
 
-  let rec merge_diverse f cmp1 s1 cmp2 s2 =
+  let merge_diverse f cmp1 s1 cmp2 s2 =
     (* This implementation does not presuppose that the comparison
        function of s1 and s2 are the same. It is necessary in the PMap
        case, were we can't enforce that the same comparison function is
@@ -659,7 +833,7 @@ module Concrete = struct
      the fast homogeneous implementation instead. This is the
      [heuristic_merge] function.
   *)
-  let rec ordered cmp s =
+  let ordered cmp s =
     if s = Empty then true else
       try
         ignore
@@ -674,7 +848,7 @@ module Concrete = struct
   (* Maps are considered compatible by their comparison function when either:
      - cmp1 and cmp2 are the *same* function (physical equality)
      - cmp1 is a correct ordering on m2 (see comment in [ordered]) *)
-  let compatible_cmp cmp1 m1 cmp2 m2 =
+  let compatible_cmp cmp1 _m1 cmp2 m2 =
     cmp1 == cmp2 || ordered cmp1 m2
 
   (* We first try to see if the comparison functions are compatible.
@@ -724,6 +898,44 @@ module Concrete = struct
         | Some v2 -> add k (f v1 v2) cmp1 m)
         m1 empty
 
+  let add_seq cmp s m =
+    BatSeq.fold_left
+      (fun m (k, v) -> add k v cmp m)
+      m
+      s
+    
+  let of_seq cmp s =
+    add_seq cmp s empty
+
+  let rec seq_of_iter m () =
+    match m with
+    | E -> BatSeq.Nil
+    | C(k, v, r, e) ->
+       BatSeq.Cons ((k, v), seq_of_iter (cons_iter r e))
+      
+  let to_seq m =
+    seq_of_iter (cons_iter m E)
+      
+  let rec rev_seq_of_iter m () =
+    match m with
+    | E -> BatSeq.Nil
+    | C(k, v, r, e) ->
+       BatSeq.Cons ((k, v), rev_seq_of_iter (rev_cons_iter r e))
+      
+  let to_rev_seq m =
+    rev_seq_of_iter (rev_cons_iter m E)
+      
+  let to_seq_from cmp k m = 
+    seq_of_iter (cons_iter_from cmp k m E)
+
+  let union_stdlib f cmp1 m1 cmp2 m2 =
+    let fwrap a b1 b2 =
+      match b1, b2 with
+      | Some b1, Some b2 -> f a b1 b2
+      | x, None
+        | None, x -> x in
+    heuristic_merge fwrap cmp1 m1 cmp2 m2
+    
   let compare ckey cval m1 m2 =
     BatEnum.compare (fun (k1,v1) (k2,v2) -> BatOrd.bin_comp ckey k1 k2 cval v1 v2) (enum m1) (enum m2)
   let equal ckey eq_val m1 m2 =
@@ -735,16 +947,24 @@ module type OrderedType = BatInterfaces.OrderedType
 module type S =
 sig
   type key
-  type (+'a) t
+  type +
+##V>=4.12## !
+  'a t
   val empty: 'a t
   val is_empty: 'a t -> bool
   val cardinal: 'a t -> int
   val add: key -> 'a -> 'a t -> 'a t
+  val update_stdlib: key -> ('a option -> 'a option) -> 'a t -> 'a t
   val update: key -> key -> 'a -> 'a t -> 'a t
   val find: key -> 'a t -> 'a
   val find_opt: key -> 'a t -> 'a option
   val find_default: 'a -> key -> 'a t -> 'a
+  val find_first: (key -> bool) -> 'a t -> key * 'a
+  val find_first_opt: (key -> bool) -> 'a t -> (key * 'a) option
+  val find_last: (key -> bool) -> 'a t -> key * 'a
+  val find_last_opt: (key -> bool) -> 'a t -> (key * 'a) option
   val remove: key -> 'a t -> 'a t
+  val remove_exn: key -> 'a t -> 'a t
   val modify: key -> ('a -> 'a) -> 'a t -> 'a t
   val modify_def: 'a -> key -> ('a -> 'a) -> 'a t -> 'a t
   val modify_opt: key -> ('a option -> 'a option) -> 'a t -> 'a t
@@ -763,10 +983,13 @@ sig
   val keys : _ t -> key BatEnum.t
   val values: 'a t -> 'a BatEnum.t
   val min_binding : 'a t -> (key * 'a)
+  val min_binding_opt : 'a t -> (key * 'a) option
   val pop_min_binding: 'a t -> (key * 'a) * 'a t
-  val max_binding : 'a t -> (key * 'a)
+  val max_binding : 'a t -> (key * 'a)    
+  val max_binding_opt : 'a t -> (key * 'a) option
   val pop_max_binding: 'a t -> (key * 'a) * 'a t
   val choose : 'a t -> (key * 'a)
+  val choose_opt : 'a t -> (key * 'a) option
   val any : 'a t -> (key * 'a)
   val split : key -> 'a t -> ('a t * 'a option * 'a t)
   val partition : (key -> 'a -> bool) -> 'a t -> 'a t * 'a t
@@ -779,8 +1002,19 @@ sig
   val exists: (key -> 'a -> bool) -> 'a t -> bool
   val merge:
     (key -> 'a option -> 'b option -> 'c option) -> 'a t -> 'b t -> 'c t
-  (** {6 Boilerplate code}*)
+  val union:
+    (key -> 'a -> 'a -> 'a option) -> 'a t -> 'a t -> 'a t
+  val to_seq : 'a t -> (key * 'a) BatSeq.t
+  val to_rev_seq : 'a t -> (key * 'a) BatSeq.t
+  val to_seq_from :  key -> 'a t -> (key * 'a) BatSeq.t
+  val add_seq : (key * 'a) BatSeq.t -> 'a t -> 'a t
+  val of_seq : (key * 'a) BatSeq.t -> 'a t
+  val to_list : 'a t -> (key * 'a) list
+  val of_list : (key * 'a) list -> 'a t
+  val add_to_list: key -> 'a -> 'a list t -> 'a list t
+
   (** {7 Printing}*)
+
   val print :  ?first:string -> ?last:string -> ?sep:string -> ?kvsep:string ->
     ('a BatInnerIO.output -> key -> unit) ->
     ('a BatInnerIO.output -> 'c -> unit) ->
@@ -833,16 +1067,19 @@ struct
   external t_of_impl: 'a implementation -> 'a t = "%identity"
   external impl_of_t: 'a t -> 'a implementation = "%identity"
 
-  type 'a iter = E | C of key * 'a * 'a implementation * 'a iter
-
   let cardinal t = Concrete.cardinal (impl_of_t t)
   let enum t = Concrete.enum (impl_of_t t)
   let backwards t = Concrete.backwards (impl_of_t t)
   let keys t = Concrete.keys (impl_of_t t)
   let values t = Concrete.values (impl_of_t t)
   let update k1 k2 v2 t = t_of_impl (Concrete.update k1 k2 v2 Ord.compare (impl_of_t t))
+  let update_stdlib k f m = t_of_impl (Concrete.update_stdlib k f Ord.compare (impl_of_t m))
   let find_default d k t = Concrete.find_default d k Ord.compare (impl_of_t t)
   let find_opt k t = Concrete.find_option k Ord.compare (impl_of_t t)
+  let find_first     f t = Concrete.find_first     f (impl_of_t t)
+  let find_first_opt f t = Concrete.find_first_opt f (impl_of_t t)
+  let find_last      f t = Concrete.find_last      f (impl_of_t t)
+  let find_last_opt  f t = Concrete.find_last_opt  f (impl_of_t t)
 
   let of_enum e = t_of_impl (Concrete.of_enum Ord.compare e)
 
@@ -881,7 +1118,11 @@ struct
     let maxi, rest = Concrete.pop_max_binding (impl_of_t t) in
     (maxi, t_of_impl rest)
 
+  let max_binding_opt t = Concrete.max_binding_opt (impl_of_t t)
+  let min_binding_opt t = Concrete.min_binding_opt (impl_of_t t)
+
   let choose t = Concrete.choose (impl_of_t t)
+  let choose_opt t = Concrete.choose_opt (impl_of_t t)
   let any t = Concrete.any (impl_of_t t)
 
   let split k t =
@@ -892,6 +1133,9 @@ struct
     let l, r = Concrete.partition p Ord.compare (impl_of_t t) in
     (t_of_impl l, t_of_impl r)
 
+  let remove_exn x m =
+    t_of_impl (Concrete.remove_exn x Ord.compare (impl_of_t m))
+
   let modify x f m = t_of_impl (Concrete.modify x f Ord.compare (impl_of_t m))
 
   let modify_def v0 x f m =
@@ -912,9 +1156,24 @@ struct
 
   let bindings t = Concrete.bindings (impl_of_t t)
 
+  let union f m1 m2 = t_of_impl (Concrete.union_stdlib f Ord.compare (impl_of_t m1) Ord.compare (impl_of_t m2))
+
   let merge f t1 t2 =
     t_of_impl (Concrete.merge f Ord.compare (impl_of_t t1) (impl_of_t t2))
 
+  let of_seq s = t_of_impl (Concrete.of_seq Ord.compare s)
+  let add_seq s m = t_of_impl (Concrete.add_seq Ord.compare s (impl_of_t m))
+  let to_seq m = Concrete.to_seq (impl_of_t m)
+  let to_rev_seq m = Concrete.to_rev_seq (impl_of_t m)
+  let to_seq_from k m = Concrete.to_seq_from Ord.compare k (impl_of_t m)
+
+  let add_to_list x data m =
+    let add = function None -> Some [data] | Some l -> Some (data :: l) in
+    update_stdlib x add m
+
+  let to_list = bindings
+  let of_list bs = List.fold_left (fun m (k, v) -> add k v m) empty bs
+
   module Exceptionless =
   struct
     let find k t = try Some (find k t) with Not_found -> None
@@ -958,12 +1217,32 @@ module String = Make (BatString)
 type ('k, 'v) t = ('k, 'v) Concrete.map
 
 let empty = Concrete.empty
-let is_empty x = x = Concrete.Empty
+let is_empty = Concrete.is_empty
+
+(*$T is_empty
+  is_empty empty
+  not(is_empty (empty |> add 1 1))
+ *)
 
 let add x d m = Concrete.add x d Pervasives.compare m
 
 let update k1 k2 v2 m = Concrete.update k1 k2 v2 Pervasives.compare m
 
+let update_stdlib k f m = Concrete.update_stdlib k f Pervasives.compare m
+
+(*$T update_stdlib
+  let of_list l = of_enum (BatList.enum l) in \
+  equal (=) (update_stdlib 1 (fun x -> assert(x = Some 1); Some 3) (of_list [1,1; 2,2]))    (of_list [1,3;2,2])
+  let of_list l = of_enum (BatList.enum l) in \
+  equal (=) (update_stdlib 3 (fun x -> assert(x = None);   Some 3) (of_list [1,1; 2,2]))    (of_list [1,1;2,2;3,3])
+  let of_list l = of_enum (BatList.enum l) in \
+  equal (=) (update_stdlib 1 (fun x -> assert(x = Some 1); None)   (of_list [1,1; 2,2]))    (of_list [2,2])
+  let of_list l = of_enum (BatList.enum l) in \
+  let s = (of_list [1,1; 2,2]) in (update_stdlib 3 (fun x -> assert(x = None  ); None  ) s) == s
+  let of_list l = of_enum (BatList.enum l) in \
+  let s = (of_list [1,1; 2,2]) in (update_stdlib 1 (fun x -> assert(x = Some 1); Some 1) s) == s
+ *)
+
 let find x m = Concrete.find x Pervasives.compare m
 
 (*$T add; find
@@ -988,21 +1267,12 @@ let find_default def x m =
 (*$T find_default
     find_default 3 4 (add 1 2 empty) = 3
     find_default 3 1 (add 1 2 empty) = 2
-*)
+ *)
 
-(*$T pop_min_binding
-  (empty |> add 1 true |> pop_min_binding) = ((1, true), empty)
-  (empty |> add 1 true |> add 2 false |> pop_min_binding) = \
-  ((1, true), add 2 false empty)
-  try ignore (pop_min_binding empty); false with Not_found -> true
-*)
-
-(*$T pop_max_binding
-  (empty |> add 1 true |> pop_max_binding) = ((1, true), empty)
-  (empty |> add 1 true |> add 2 false |> pop_max_binding) = \
-  ((2, false), add 1 true empty)
-  try ignore (pop_max_binding empty); false with Not_found -> true
-*)
+let find_first f map = Concrete.find_first f map
+let find_first_opt f map = Concrete.find_first_opt f map
+let find_last f map = Concrete.find_last f map
+let find_last_opt f map = Concrete.find_last_opt f map
 
 (*$Q find ; add
   (Q.list Q.small_int) (fun xs -> \
@@ -1019,6 +1289,18 @@ let remove x m = Concrete.remove x Pervasives.compare m
   List.fold_left (fun acc x -> remove x acc) (of_list xs true empty) xs |> is_empty)
 *)
 
+let remove_exn x m = Concrete.remove_exn x Pervasives.compare m
+
+(*$Q add ; remove_exn
+  (Q.list Q.small_int) (fun xs -> \
+  let xs = List.unique xs in \
+  let of_list xs y m0 = List.fold_left (fun acc x -> add x y acc) m0 xs in \
+  List.fold_left (fun acc x -> remove_exn x acc) (of_list xs true empty) xs |> is_empty)
+*)
+(*$T remove_exn
+  try remove_exn 1 empty |> ignore ; false with Not_found -> true
+*)
+
 let mem x m = Concrete.mem x Pervasives.compare m
 
 let iter = Concrete.iter
@@ -1057,11 +1339,111 @@ let filter f t = Concrete.filter f t Pervasives.compare
 let filter_map f t = Concrete.filter_map f t Pervasives.compare
 
 let choose = Concrete.choose
+let choose_opt = Concrete.choose_opt
 let any = Concrete.any
 let max_binding = Concrete.max_binding
 let min_binding = Concrete.min_binding
+let max_binding_opt = Concrete.max_binding_opt
+let min_binding_opt = Concrete.min_binding_opt
 let pop_min_binding = Concrete.pop_min_binding
 let pop_max_binding = Concrete.pop_max_binding
+                    
+(*$T pop_min_binding
+  (empty |> add 1 true |> pop_min_binding) = ((1, true), empty)
+  (empty |> add 1 true |> add 2 false |> pop_min_binding) = \
+  ((1, true), add 2 false empty)
+  try ignore (pop_min_binding empty); false with Not_found -> true
+*)
+
+(*$T pop_max_binding
+  (empty |> add 1 true |> pop_max_binding) = ((1, true), empty)
+  (empty |> add 1 true |> add 2 false |> pop_max_binding) = \
+  ((2, false), add 1 true empty)
+  try ignore (pop_max_binding empty); false with Not_found -> true
+*)
+
+(*$T choose
+  let of_list l = of_enum (BatList.enum l) in \
+  (1,1) = choose (of_list [1,1])
+  try ignore(choose empty); false with Not_found -> true
+ *)
+                    
+(*$T choose_opt
+  let of_list l = of_enum (BatList.enum l) in \
+  Some (1,1) = choose_opt (of_list [1,1])
+  None = choose_opt (empty)
+ *)
+
+(*$T max_binding
+  let of_list l = of_enum (BatList.enum l) in \
+  (3,3) = max_binding (of_list [1,1;2,2;3,3])
+  try ignore(max_binding empty); false with Not_found -> true
+ *)
+                    
+(*$T max_binding_opt
+  let of_list l = of_enum (BatList.enum l) in \
+  Some (3,3) = max_binding_opt (of_list [1,1;2,2;3,3])
+  None = max_binding_opt empty
+ *)
+                    
+(*$T min_binding
+  let of_list l = of_enum (BatList.enum l) in \
+  (1,1) = min_binding (of_list [1,1;2,2;3,3])
+  try ignore(min_binding empty); false with Not_found -> true
+ *)
+                    
+(*$T min_binding_opt
+  let of_list l = of_enum (BatList.enum l) in \
+  Some (1,1) = min_binding_opt (of_list [1,1;2,2;3,3])
+  None = min_binding_opt empty
+ *)
+
+(*$T add
+  let s = empty |> add 1 1 |> add 2 2 in s == (s |> add 2 2)
+  *)
+
+(*$T remove
+  let s = empty |> add 1 1 |> add 2 2 in s == (s |> remove 4)
+  *)
+
+(*$T update
+  let s = empty |> add 1 1 |> add 2 2 in \
+  s == (s |> update 2 2 2)
+  *)
+
+(*$T update_stdlib
+  let s = empty |> add 1 1 |> add 2 2 in \
+  s == (s |> update_stdlib 2 (fun _ -> Some 2))
+  *)
+
+(*$T filter
+  let s = empty |> add 1 1 |> add 2 2 in \
+  s == (filter (fun _ _ -> true) s)
+  *)
+
+                    
+let of_seq s =
+  Concrete.of_seq Pervasives.compare s
+
+let add_seq s m =
+  Concrete.add_seq Pervasives.compare s m
+
+let to_seq = Concrete.to_seq
+let to_rev_seq = Concrete.to_rev_seq
+
+let to_seq_from x m =
+  Concrete.to_seq_from Pervasives.compare x m
+
+let union_stdlib f m1 m2 = Concrete.union_stdlib f Pervasives.compare m1 Pervasives.compare m2
+(*$T union_stdlib
+  equal (=) (union_stdlib (fun _ -> failwith "must not be called") empty empty) empty
+  let of_list l = of_enum (BatList.enum l) in \
+  equal (=) (union_stdlib (fun _ -> failwith "must not be called") (of_list [1,1;2,2]) empty) (of_list [1,1;2,2])
+  let of_list l = of_enum (BatList.enum l) in \
+  equal (=) (union_stdlib (fun _ -> failwith "must not be called") empty (of_list [1,1;2,2])) (of_list [1,1;2,2])
+  let of_list l = of_enum (BatList.enum l) in \
+  equal (=) (union_stdlib (fun _ -> failwith "must not be called") (of_list [3,3;4,4]) (of_list [1,1;2,2])) (of_list [1,1;2,2;3,3;4,4])
+ *)
 
 let singleton k v = Concrete.singleton k v
 
@@ -1094,7 +1476,6 @@ let pop = Concrete.pop
 
 let split k m = Concrete.split k Pervasives.compare m
 
-
 (* We can't compare external primitives directly using the physical equality
    operator, since two different occurrences of an external primitive are two
    different closures. So we first make a local binding of [Pervasives.compare]
@@ -1109,7 +1490,10 @@ let union m1 m2 =
   let m1 = empty |> add 1 1 |> add 2 2 in \
   let m2 = empty |> add 2 20 |> add 3 30 in \
   (union m1 m2 |> find 2 = 20) && (union m2 m1 |> find 2 = 2)
-*)
+ *)
+
+let union_stdlib f m1 m2 =
+  Concrete.union_stdlib f Pervasives.compare m1 Pervasives.compare m2
 
 let diff m1 m2 =
   let comp = Pervasives.compare in
@@ -1125,7 +1509,7 @@ let merge f m1 m2 = Concrete.merge f Pervasives.compare m1 m2
 let bindings = Concrete.bindings
 
 let compare cmp_val m1 m2 =
-  Concrete.compare Pervasives.compare Pervasives.compare m1 m2
+  Concrete.compare Pervasives.compare cmp_val m1 m2
 
 let equal eq_val m1 m2 = Concrete.equal Pervasives.compare eq_val m1 m2
 
@@ -1156,7 +1540,7 @@ module PMap = struct (*$< PMap *)
     }
 
   let create cmp = { cmp = cmp; map = Concrete.empty }
-  let get_cmp {cmp} = cmp
+  let get_cmp {cmp; _} = cmp
 
   (*$T get_cmp
     get_cmp (create BatInt.compare) == BatInt.compare
@@ -1167,10 +1551,22 @@ module PMap = struct (*$< PMap *)
   let is_empty x = x.map = Concrete.Empty
 
   let add x d m =
-    { m with map = Concrete.add x d m.cmp m.map }
+    let newmap = Concrete.add x d m.cmp m.map in
+    if newmap == m.map
+    then m
+    else { m with map = newmap }
 
   let update k1 k2 v2 m =
-    { m with map = Concrete.update k1 k2 v2 m.cmp m.map }
+    let newmap = Concrete.update k1 k2 v2 m.cmp m.map in
+    if newmap == m.map
+    then m
+    else { m with map = newmap }
+
+  let update_stdlib k f m =
+    let newmap = Concrete.update_stdlib k f m.cmp m.map in
+    if newmap == m.map
+    then m
+    else { m with map = newmap }
 
   let find x m =
     Concrete.find x m.cmp m.map
@@ -1195,6 +1591,12 @@ module PMap = struct (*$< PMap *)
     find_default 3 1 (add 1 2 empty) = 2
   *)
 
+  let find_first f map = Concrete.find_first f map.map
+  let find_first_opt f map = Concrete.find_first_opt f map.map
+  let find_last f map = Concrete.find_last f map.map
+  let find_last_opt f map = Concrete.find_last_opt f map.map
+
+    
   (*$T update
     add 1 false empty |> update 1 1 true |> find 1
     add 1 false empty |> update 1 2 true |> find 2
@@ -1219,6 +1621,19 @@ module PMap = struct (*$< PMap *)
     let of_list xs y m0 = List.fold_left (fun acc x -> add x y acc) m0 xs in \
     List.fold_left (fun acc x -> remove x acc) (of_list xs true empty) xs |> is_empty)
   *)
+  let remove_exn x m =
+    { m with map = Concrete.remove_exn x m.cmp m.map }
+
+  (*$Q add ; remove_exn
+    (Q.list Q.small_int) (fun xs -> \
+    let xs = List.unique xs in \
+    let of_list xs y m0 = List.fold_left (fun acc x -> add x y acc) m0 xs in \
+    List.fold_left (fun acc x -> remove_exn x acc) (of_list xs true empty) xs |> is_empty)
+  *)
+  (*$T remove_exn
+    add 1 false empty |> remove_exn 1 |> mem 1 |> not
+    try remove_exn 1 empty |> ignore ; false with Not_found -> true
+  *)
 
   let mem x m =
     Concrete.mem x m.cmp m.map
@@ -1268,11 +1683,17 @@ module PMap = struct (*$< PMap *)
     Concrete.print ?first ?last ?sep ?kvsep print_k print_v out t.map
 
   let filterv  f t = { t with map = Concrete.filterv f t.map t.cmp }
-  let filter f t = { t with map = Concrete.filter f t.map t.cmp }
   let filter_map f t = { t with map = Concrete.filter_map f t.map t.cmp }
+  let filter f t =
+    let newmap =  Concrete.filter f t.map t.cmp in
+    if newmap == t.map
+    then t
+    else { t with map = newmap }
 
   let max_binding t = Concrete.max_binding t.map
   let min_binding t = Concrete.min_binding t.map
+  let max_binding_opt t = Concrete.max_binding_opt t.map
+  let min_binding_opt t = Concrete.min_binding_opt t.map
   let pop_min_binding m =
     let mini, rest = Concrete.pop_min_binding m.map in
     (mini, { m with map = rest })
@@ -1294,6 +1715,7 @@ module PMap = struct (*$< PMap *)
   let cardinal m = Concrete.cardinal m.map
 
   let choose m = Concrete.choose m.map
+  let choose_opt m = Concrete.choose_opt m.map
   let any m = Concrete.any m.map
 
   let split k m =
@@ -1340,6 +1762,22 @@ module PMap = struct (*$< PMap *)
   let merge_unsafe f m1 m2 =
     { m1 with map = Concrete.merge f m1.cmp m1.map m2.map }
 
+  let of_seq ?(cmp = Pervasives.compare) s =
+    { map = Concrete.of_seq cmp s; cmp = cmp }
+    
+  let to_seq m = Concrete.to_seq m.map
+
+  let to_rev_seq m = Concrete.to_rev_seq m.map
+             
+  let to_seq_from k m =
+    Concrete.to_seq_from m.cmp k m.map
+                      
+  let add_seq s m =
+    { m with map = Concrete.add_seq m.cmp s m.map }
+
+  let union_stdlib f m1 m2 =
+    { m1 with map = Concrete.union_stdlib f m1.cmp m1.map m2.cmp m2.map }
+
   let bindings m =
     Concrete.bindings m.map
 
