@@ -33,7 +33,7 @@
     @documents Random
 *)
 
-(** {6 Basic functions} *)
+(** {1 Basic functions} *)
 
 val init : int -> unit
 (** Initialize the generator, using the argument as a seed.
@@ -65,14 +65,20 @@ val int : int -> int
 ##V>=4.13##
 ##V>=4.13##    @since 3.4.0 and OCaml 4.13.0 *)
 
+##V>=5.2##val int_in_range : min:int -> max:int -> int
+
 val int32 : Int32.t -> Int32.t
 (** [Random.int32 bound] returns a random integer between 0 (inclusive)
      and [bound] (exclusive).  [bound] must be greater than 0. *)
 
+##V>=5.2##val int32_in_range : min:int32 -> max:int32 -> int32
+
 val nativeint : Nativeint.t -> Nativeint.t
 (** [Random.nativeint bound] returns a random integer between 0 (inclusive)
      and [bound] (exclusive).  [bound] must be greater than 0. *)
 
+##V>=5.2##val nativeint_in_range : min:nativeint -> max:nativeint -> nativeint
+
 val int64 : Int64.t -> Int64.t
 (** [Random.int64 bound] returns a random integer between 0 (inclusive)
      and [bound] (exclusive).  [bound] must be greater than 0. *)
@@ -83,6 +89,8 @@ val float : float -> float
     negative, the result is negative or zero.  If [bound] is 0,
     the result is 0. *)
 
+##V>=5.2##val int64_in_range : min:int64 -> max:int64 -> int64
+
 val bool : unit -> bool
 (** [Random.bool ()] returns [true] or [false] with probability 0.5 each. *)
 
@@ -99,7 +107,7 @@ val full_range_int : unit -> int
     platforms, so is not portable. *)
 
 
-(** {6 Enumerations of random values.} *)
+(** {1 Enumerations of random values.} *)
 
 val enum_bits  : unit    -> int BatEnum.t
 
@@ -119,7 +127,7 @@ val enum_char : unit -> char BatEnum.t
 
 (*val enum_uchar : unit -> UChar.t BatEnum.t*)
 
-(** {6 Working with data structures.} *)
+(** {1 Working with data structures.} *)
 
 val choice : 'a BatEnum.t -> 'a
 (** [choice e] returns a randomly-chosen element of [e].
@@ -159,7 +167,7 @@ val shuffle: 'a BatEnum.t -> 'a array
 ##V>=4.14##    {!Nativeint.min_int} and {!Nativeint.max_int}.
 ##V>=4.14##    @since 4.14.0 *)
 
-(** {6 Advanced functions} *)
+(** {1 Advanced functions} *)
 
 (** Manipulate the current state of the random generator.
 
@@ -184,9 +192,13 @@ module State : sig
   val bits       : t -> int
   val int        : t -> int -> int
 ##V>=4.13##val full_int : t -> int -> int
+##V>=5.2##val int_in_range : t -> min:int -> max:int -> int
   val int32      : t -> Int32.t -> Int32.t
+##V>=5.2##val int32_in_range : t -> min:int32 -> max:int32 -> int32
   val nativeint  : t -> Nativeint.t -> Nativeint.t
+##V>=5.2##val nativeint_in_range : t -> min:nativeint -> max:nativeint -> nativeint
   val int64      : t -> Int64.t -> Int64.t
+##V>=5.2##val int64_in_range : t -> min:int64 -> max:int64 -> int64
   val float      : t -> float -> float
   val bool       : t -> bool
   val char       : t -> char
