@@ -103,7 +103,10 @@ let rec cfind ?(cx=[]) ~sel = function
  *)
 
 module StrongRef : sig
-  type +'a t
+  type +
+##V>=4.12## !
+  'a t
+
   val ref : 'a -> 'a t
   val get : 'a t -> 'a
   val set : 'a t -> 'a -> unit
@@ -263,7 +266,7 @@ struct
       csplay begin
         match cfind ~sel:(ksel k) tr with
         | C (cx, Node (l, (k, v), r)) -> C (cx, Node (l, (k, fn v), r))
-        | C (cx, Empty) -> raise Not_found
+        | C (_cx, Empty) -> raise Not_found
       end
     end
 
@@ -314,6 +317,98 @@ struct
     try find k m
     with Not_found -> def
 
+  let rec find_first_helper_found f kv map = function
+    | Node (l, (k, v), r) ->
+       if f k
+       then find_first_helper_found f (k, v) map l
+       else find_first_helper_found f kv map r
+    | Empty -> 
+       (* dummy find to rebalance the tree *)
+       ignore(find (fst kv) map);
+       kv
+             
+  let find_first f (map : 'a t) =
+    let rec loop_notfound f = function
+      | Node(l, (k, v), r) ->
+         if f k
+         then find_first_helper_found f (k, v) map l
+         else loop_notfound f r
+      | Empty -> raise Not_found in
+    loop_notfound f (sget map)
+
+  let find_first_opt f map =
+    let rec loop_notfound f = function
+      | Node(l, (k, v), r) ->
+         if f k
+         then Some (find_first_helper_found f (k, v) map l)
+         else loop_notfound f r
+      | Empty -> None in
+    loop_notfound f (sget map)
+
+  let rec find_last_helper_found f kv map = function
+    | Node (l, (k, v), r) ->
+       if f k
+       then find_last_helper_found f (k, v) map r
+       else find_last_helper_found f kv map l
+    | Empty ->
+       (* dummy find to rebalance the tree *)
+       ignore(find (fst kv) map);
+       kv
+    
+  let find_last f (map : 'a t) =
+    let rec loop_notfound f = function
+      | Node(l, (k, v), r) ->
+         if f k
+         then find_last_helper_found f (k, v) map r
+         else loop_notfound f l
+      | Empty -> raise Not_found in
+    loop_notfound f (sget map)
+
+  let find_last_opt f map =
+    let rec loop_notfound f = function
+      | Node(l, (k, v), r) ->
+         if f k
+         then Some (find_last_helper_found f (k, v) map r)
+         else loop_notfound f l
+      | Empty -> None in
+    loop_notfound f (sget map)
+                    
+  (*$T find_first
+              (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_first (fun x -> x >= 0)) = ((1, 11))
+              (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_first (fun x -> x >= 1)) = ((1, 11))
+              (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_first (fun x -> x >= 2)) = ((2, 12))
+              (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_first (fun x -> x >= 3)) = ((3, 13))
+    try ignore(empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_first (fun x -> x >= 4)); false with Not_found -> true
+    try ignore(empty |>                                     find_first (fun x -> x >= 3)); false with Not_found -> true
+  *)
+
+  (*$T find_first_opt
+    (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_first_opt (fun x -> x >= 0)) = (Some (1, 11))
+    (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_first_opt (fun x -> x >= 1)) = (Some (1, 11))
+    (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_first_opt (fun x -> x >= 2)) = (Some (2, 12))
+    (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_first_opt (fun x -> x >= 3)) = (Some (3, 13))
+    (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_first_opt (fun x -> x >= 4)) = (None)
+    (empty |>                                     find_first_opt (fun x -> x >= 3)) = (None)
+  *)
+
+  (*$T find_last
+              (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_last (fun x -> x <= 1)) = (1, 11)
+              (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_last (fun x -> x <= 2)) = (2, 12)
+              (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_last (fun x -> x <= 3)) = (3, 13)
+              (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_last (fun x -> x <= 4)) = (3, 13)
+    try ignore(empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_last (fun x -> x <= 0)); false with Not_found -> true
+    try ignore(empty |>                                     find_last (fun x -> x <= 3)); false with Not_found -> true
+  *)
+
+  (*$T find_last_opt
+    (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_last_opt (fun x -> x <= 0)) = None
+    (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_last_opt (fun x -> x <= 1)) = Some (1, 11)
+    (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_last_opt (fun x -> x <= 2)) = Some (2, 12)
+    (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_last_opt (fun x -> x <= 3)) = Some (3, 13)
+    (empty |> add 1 11 |> add 2 12 |> add 3 13 |> find_last_opt (fun x -> x <= 4)) = Some (3, 13)
+    (empty |>                                     find_last_opt (fun x -> x <= 3)) = None
+  *)
+
   let cchange fn (C (cx, t)) = C (cx, fn t)
 
   let remove k tr =
@@ -325,6 +420,19 @@ struct
     let tr = top (cchange replace (cfind ~sel:(ksel k) tr)) in
     sref tr
 
+  let remove_exn k tr =
+    let tr = sget tr in
+    let replace = function
+      | Empty -> raise Not_found
+      | Node (l, _, r) -> bst_append l r
+    in
+    let tr = top (cchange replace (cfind ~sel:(ksel k) tr)) in
+    sref tr
+
+  (*$T remove_exn
+    try remove_exn 1 empty |> ignore ; false with Not_found -> true
+  *)
+
   let update k1 k2 v2 tr =
     if Ord.compare k1 k2 <> 0 then
       add k2 v2 (remove k1 tr)
@@ -334,10 +442,15 @@ struct
         csplay begin
           match cfind ~sel:(ksel k1) tr with
           | C (cx, Node (l, _kv, r)) -> C (cx, Node (l, (k2, v2), r))
-          | C (cx, Empty) -> raise Not_found
+          | C (_cx, Empty) -> raise Not_found
         end
       end
 
+  let update_stdlib k f m =
+    match f (find_opt k m) with
+    | Some x -> add k x m
+    | None -> remove k m
+
   let mem k m =
     try ignore (find k m) ; true with Not_found -> false
 
@@ -372,6 +485,16 @@ struct
     in
     bfind tr
 
+  let min_binding_opt tr =
+    let tr = sget tr in
+    let rec bfind = function
+      | Node (Empty, kv, _) -> Some kv
+      | Node (l, _, _) -> bfind l
+      | Empty -> None
+    in
+    bfind tr
+        
+
   let choose = min_binding
   (*$= choose
     (empty |> add 0 1 |> add 1 1 |> choose) \
@@ -380,7 +503,8 @@ struct
   (*$T choose
     try ignore (choose empty) ; false with Not_found -> true
   *)
-
+  let choose_opt  = min_binding_opt
+                  
   let any tr = match sget tr with
     | Empty -> raise Not_found
     | Node (_, kv, _) -> kv
@@ -393,7 +517,7 @@ struct
     let rec bfind = function
       | Node (Empty, kv, r) -> mini := kv; r
       | Node (l, kv, r) -> Node (bfind l, kv, r)
-      | Empty -> assert(false)
+      | Empty ->  assert(false)  (* choose already raises Not_found on empty map *)
     in
     (!mini, sref (bfind (sget tr)))
 
@@ -406,12 +530,21 @@ struct
     in
     bfind tr
 
+  let max_binding_opt tr =
+    let tr = sget tr in
+    let rec bfind = function
+      | Node (_, kv, Empty) -> Some kv
+      | Node (_, _, r) -> bfind r
+      | Empty -> None
+    in
+    bfind tr
+        
   let pop_max_binding tr =
     let maxi = ref (choose tr) in
     let rec bfind = function
       | Node (l, kv, Empty) -> maxi := kv; l
       | Node (l, kv, r) -> Node (l, kv, bfind r)
-      | Empty -> assert(false)
+      | Empty ->  assert(false)  (* choose already raises Not_found on empty map *)
     in
     (!maxi, sref (bfind (sget tr)))
 
@@ -479,6 +612,14 @@ struct
     | Node (l, (k, v), r) ->
       rev_cons_enum r (More (k, v, l, e))
 
+  let rec cons_enum_from k2 m e =
+    match m with
+    | Empty -> e
+    | Node (l, (k, v), r) ->
+       if Ord.compare k2 k <= 0
+       then cons_enum_from k2 l (More (k, v, r, e))
+       else cons_enum_from k2 r e
+
   let compare cmp tr1 tr2 =
     let tr1, tr2 = sget tr1, sget tr2 in
     let rec aux e1 e2 = match (e1, e2) with
@@ -529,6 +670,9 @@ struct
 
   let to_list m = List.of_enum (enum m)
   let of_list l = of_enum (List.enum l)
+  let add_to_list x data m =
+    let add = function None -> Some [data] | Some l -> Some (data :: l) in
+    update_stdlib x add m
 
   let custom_print ~first ~last ~sep kvpr out m =
     Enum.print ~first ~last ~sep
@@ -664,6 +808,43 @@ struct
     | Empty -> raise Not_found
     | Node (l, kv, r) -> kv, sref (bst_append l r)
 
+
+  let add_seq s m =
+    BatSeq.fold_left
+      (fun m (k, v) -> add k v m)
+      m
+      s
+    
+  let of_seq s =
+    add_seq s empty
+
+  let rec seq_of_iter m () =
+    match m with
+    | End -> BatSeq.Nil
+    | More(k, v, r, e) ->
+       BatSeq.Cons ((k, v), seq_of_iter (cons_enum r e))
+      
+  let to_seq m =
+    seq_of_iter (cons_enum (sget m) End)
+
+  let to_rev_seq m =
+    seq_of_iter (rev_cons_enum (sget m) End)
+
+  let to_seq_from k m =
+    seq_of_iter (cons_enum_from k (sget m) End)
+   
+  let union f m1 m2 =
+    fold
+     (fun k v m ->
+        match find_opt k m with
+        | Some v1 ->
+           (match f k v v1 with
+            | Some vmerged -> add k vmerged m
+            | None -> remove k m)
+        | None -> add k v m)
+      m1
+      m2
+                         
   let extract k tr =
     let tr = sget tr in
     (* the reference here is a tad ugly but allows to reuse `cfind`
@@ -682,3 +863,5 @@ struct
     | Some v -> v, sref tr
   (*$>*)
 end
+  
+
