@@ -116,8 +116,6 @@ module ArrayContainer : Container = struct
   let hd = ni1
   let snoc = ni1
   let cons = ni1
-  let take = head
-  let drop = tail
   let tail = ni1
   let init = ni1
   and find_right = ni2
